/***************************************************************************
 *   Copyright (C) 2008-2009 by Marcel Hasler                              *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KOSD_H
#define KOSD_H

#include <KActionCollection>
#include <KUniqueApplication>
#include <KConfigSkeleton>
#include <KAboutApplicationDialog>

#include "configurationdialog.h"
#include "osd.h"
#include "powermanager.h"
#include "mixer.h"

class KOSD : public KUniqueApplication
{
	Q_OBJECT
public:
	KOSD();
	~KOSD();

	int newInstance();

public slots:
	// DBUS interface
	Q_SCRIPTABLE void showCustom(QString icon, QString label, int percent);

	Q_SCRIPTABLE void raiseVolume();
	Q_SCRIPTABLE void lowerVolume();
	Q_SCRIPTABLE void muteVolume();
	Q_SCRIPTABLE void showVolume();
	Q_SCRIPTABLE void setVolume(int volume);

	Q_SCRIPTABLE void showBrightness();
	Q_SCRIPTABLE void showBrightnessUp();
	Q_SCRIPTABLE void showBrightnessDown();
	Q_SCRIPTABLE void setBrightness(int brightness);

	Q_SCRIPTABLE void showBattery();

private slots:
	void slotShowConfigDialog();
	void slotConfigDialogFinished();

	void slotShowShortcutsDialog();

	void slotShowAboutDialog();
	void slotAboutDialogFinished();

	void slotApplySettings();

private:
	QString findBatteryIcon();
	QString findVolumeIcon(unsigned int volume);

	Mixer *m_mixer;
	PowerManager *m_powermanager;
	KActionCollection *m_actions;
	OSD *m_osd;

	KConfigSkeleton *m_settings;
	ConfigurationDialog *m_configDialog;

	KAboutApplicationDialog *m_aboutDialog;
};

#endif // KOSD_H
